==> odata-client-microsoft-dynamics-0.1.38-sources.jar: microsoft/dynamics/crm/entity/collection/request/MobileofflineprofileitemCollectionRequest.java <==
package microsoft.dynamics.crm.entity.collection.request;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.github.davidmoten.odata.client.CollectionPageEntityRequest;
import com.github.davidmoten.odata.client.CollectionPageNonEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.annotation.Function;
import com.github.davidmoten.odata.client.internal.ParameterMap;
import com.github.davidmoten.odata.client.internal.RequestHelper;
import com.github.davidmoten.odata.client.internal.TypedObject;

import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Mobileofflineprofileitem;
import microsoft.dynamics.crm.entity.request.MobileofflineprofileitemRequest;
import microsoft.dynamics.crm.entity.request.MobileofflineprofileitemassociationRequest;
import microsoft.dynamics.crm.schema.SchemaInfo;

public class MobileofflineprofileitemCollectionRequest extends CollectionPageEntityRequest<Mobileofflineprofileitem, MobileofflineprofileitemRequest>{

    protected ContextPath contextPath;

    public MobileofflineprofileitemCollectionRequest(ContextPath contextPath, Optional<Object> value) {
        super(contextPath, Mobileofflineprofileitem.class, cp -> new MobileofflineprofileitemRequest(cp, Optional.empty()), SchemaInfo.INSTANCE, value);
        this.contextPath = contextPath;
    }

    public MobileofflineprofileitemassociationCollectionRequest mobileOfflineProfileItem_MobileOfflineProfileItemAssociation() {
        return new MobileofflineprofileitemassociationCollectionRequest(contextPath.addSegment("MobileOfflineProfileItem_MobileOfflineProfileItemAssociation"), Optional.empty());
    }

    public MobileofflineprofileitemassociationRequest mobileOfflineProfileItem_MobileOfflineProfileItemAssociation(String mobileofflineprofileitemassociationid) {
        return new MobileofflineprofileitemassociationRequest(contextPath.addSegment("MobileOfflineProfileItem_MobileOfflineProfileItemAssociation").addKeys(new NameValue(mobileofflineprofileitemassociationid.toString())), Optional.empty());
    }

    @Function(name = "RetrieveUnpublishedMultiple")
    @JsonIgnore
    public CollectionPageNonEntityRequest<Mobileofflineprofileitem> retrieveUnpublishedMultiple() {
        Map<String, TypedObject> _parameters = ParameterMap.empty();
        return CollectionPageNonEntityRequest.forFunction(this.contextPath.addActionOrFunctionSegment("Microsoft.Dynamics.CRM.RetrieveUnpublishedMultiple"), Mobileofflineprofileitem.class, _parameters, microsoft.dynamics.crm.schema.SchemaInfo.INSTANCE);
    }

}

==> odata-client-microsoft-dynamics-0.1.39-sources.jar: microsoft/dynamics/crm/entity/collection/request/MobileofflineprofileitemCollectionRequest.java <==
package microsoft.dynamics.crm.entity.collection.request;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.github.davidmoten.odata.client.CollectionPageEntityRequest;
import com.github.davidmoten.odata.client.CollectionPageNonEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.annotation.Function;
import com.github.davidmoten.odata.client.internal.ParameterMap;
import com.github.davidmoten.odata.client.internal.RequestHelper;
import com.github.davidmoten.odata.client.internal.TypedObject;

import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Mobileofflineprofileitem;
import microsoft.dynamics.crm.entity.request.MobileofflineprofileitemRequest;
import microsoft.dynamics.crm.entity.request.MobileofflineprofileitemassociationRequest;

public class MobileofflineprofileitemCollectionRequest extends CollectionPageEntityRequest<Mobileofflineprofileitem, MobileofflineprofileitemRequest>{

    protected ContextPath contextPath;

    public MobileofflineprofileitemCollectionRequest(ContextPath contextPath, Optional<Object> value) {
        super(contextPath, Mobileofflineprofileitem.class, cp -> new MobileofflineprofileitemRequest(cp, Optional.empty()), value);
        this.contextPath = contextPath;
    }

    public MobileofflineprofileitemassociationCollectionRequest mobileOfflineProfileItem_MobileOfflineProfileItemAssociation() {
        return new MobileofflineprofileitemassociationCollectionRequest(contextPath.addSegment("MobileOfflineProfileItem_MobileOfflineProfileItemAssociation"), Optional.empty());
    }

    public MobileofflineprofileitemassociationRequest mobileOfflineProfileItem_MobileOfflineProfileItemAssociation(String mobileofflineprofileitemassociationid) {
        return new MobileofflineprofileitemassociationRequest(contextPath.addSegment("MobileOfflineProfileItem_MobileOfflineProfileItemAssociation").addKeys(new NameValue(mobileofflineprofileitemassociationid.toString())), Optional.empty());
    }

    @Function(name = "RetrieveUnpublishedMultiple")
    @JsonIgnore
    public CollectionPageNonEntityRequest<Mobileofflineprofileitem> retrieveUnpublishedMultiple() {
        Map<String, TypedObject> _parameters = ParameterMap.empty();
        return CollectionPageNonEntityRequest.forFunction(this.contextPath.addActionOrFunctionSegment("Microsoft.Dynamics.CRM.RetrieveUnpublishedMultiple"), Mobileofflineprofileitem.class, _parameters);
    }

}
